aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/keypair_details/KeyUIDSignDialog.h
diff options
context:
space:
mode:
authorSaturneric <[email protected]>2021-12-05 06:18:14 +0000
committerSaturneric <[email protected]>2021-12-05 06:18:14 +0000
commitad423ba4cf529a5d5223c7808596caa7e52aab3a (patch)
treea6d05a7f32e9d6c47551c6568381d8b4d558da4b /src/ui/keypair_details/KeyUIDSignDialog.h
parentUpdate Documents. (diff)
parentFixed (diff)
downloadGpgFrontend-ad423ba4cf529a5d5223c7808596caa7e52aab3a.tar.gz
GpgFrontend-ad423ba4cf529a5d5223c7808596caa7e52aab3a.zip
Merge branch 'develop-ci' into develop
Diffstat (limited to '')
-rw-r--r--src/ui/keypair_details/KeyUIDSignDialog.h (renamed from include/ui/keypair_details/KeyUIDSignDialog.h)44
1 files changed, 22 insertions, 22 deletions
diff --git a/include/ui/keypair_details/KeyUIDSignDialog.h b/src/ui/keypair_details/KeyUIDSignDialog.h
index 88549e95..8a83977a 100644
--- a/include/ui/keypair_details/KeyUIDSignDialog.h
+++ b/src/ui/keypair_details/KeyUIDSignDialog.h
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -25,40 +25,40 @@
#ifndef GPGFRONTEND_KEYUIDSIGNDIALOG_H
#define GPGFRONTEND_KEYUIDSIGNDIALOG_H
-#include "GpgFrontend.h"
-
#include "gpg/GpgContext.h"
+#include "ui/GpgFrontendUI.h"
#include "ui/widgets/KeyList.h"
-class KeyUIDSignDialog : public QDialog {
- Q_OBJECT
-
-public:
+namespace GpgFrontend::UI {
- explicit KeyUIDSignDialog(GpgME::GpgContext *ctx, const GpgKey &key, const QVector<GpgUID> &uid, QWidget *parent = nullptr);
-
-private:
-
- GpgME::GpgContext *mCtx;
+class KeyUIDSignDialog : public QDialog {
+ Q_OBJECT
- KeyList *mKeyList;
+ public:
+ explicit KeyUIDSignDialog(const GpgKey& key, UIDArgsListPtr uid,
+ QWidget* parent = nullptr);
- QPushButton *signKeyButton;
+ signals:
+ void signalKeyUIDSignUpdate();
- QDateTimeEdit *expiresEdit;
+ private:
+ KeyList* mKeyList;
- QCheckBox *nonExpireCheck;
+ QPushButton* signKeyButton;
- const QVector<GpgUID> mUids;
+ QDateTimeEdit* expiresEdit;
- const GpgKey &mKey;
+ QCheckBox* nonExpireCheck;
+ UIDArgsListPtr mUids;
-private slots:
+ const GpgKey& mKey;
- void slotSignKey(bool clicked);
+ private slots:
+ void slotSignKey(bool clicked);
};
+} // namespace GpgFrontend::UI
-#endif //GPGFRONTEND_KEYUIDSIGNDIALOG_H
+#endif // GPGFRONTEND_KEYUIDSIGNDIALOG_H
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or